# Overview
**osqur** (pronounced "Oscar") is a Python module built to facilitate quantitative user experience (UX) research.
It is built on top of pandas 2.0 with `scikit-learn`-like APIs. The package name is an acronym for Open Source Quantiative UX Research.
